@@ -71,7 +71,7 @@ class DjangoCodeMirrorSettingsForm(forms.Form):
     
     def __init__(self, *args, **kwargs):
         self.helper = get_form_helper()
-        if self.helper:
+        if self.helper is not None:
             self.helper.form_action = reverse('djangocodemirror-settings')
         
         super(DjangoCodeMirrorSettingsForm, self).__init__(*args, **kwargs)
